pub type Dict<T> = Vec<DictEntry<T>>;Aliased Type
pub struct Dict<T> { /* private fields */ }Trait Implementations
Sourceimpl<T> DictIface<T> for Dict<T>
impl<T> DictIface<T> for Dict<T>
Sourcefn add(&mut self, key: String, val: T) -> bool
fn add(&mut self, key: String, val: T) -> bool
Add an element val of type T, indexed by the string key. Returns false if the key exists or there is a hash collision
Sourcefn remove_key(&mut self, key: &str) -> Option<T>
fn remove_key(&mut self, key: &str) -> Option<T>
Remove the element identified by the key key and return it, if exists.
Sourcefn get(&self, key: &str) -> Option<&T>
fn get(&self, key: &str) -> Option<&T>
Return a reference to the value identified by the key key, if exists.
Sourcefn contains_key(&self, key: &str) -> bool
fn contains_key(&self, key: &str) -> bool
Return true if an element identified by the key key exists.